#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 idris
version:              1.3.3
visibility:           public
id:                   idris-1.3.3-FqpR8juFX0xIMsxhVdonFO
key:                  idris-1.3.3-FqpR8juFX0xIMsxhVdonFO
license:              BSD-3-Clause
maintainer:           Niklas Larsson <niklas@mm.st>
author:               Edwin Brady
stability:            Beta
homepage:             https://www.idris-lang.org/
synopsis:             Functional Programming Language with Dependent Types
description:
    Idris is a general purpose language with full dependent types.
    It is compiled, with eager evaluation.
    Dependent types allow types to be predicated on values,
    meaning that some aspects of a program'\''s behaviour can be
    specified precisely in the type. The language is closely
    related to Epigram and Agda. There is a tutorial at
    <https://www.idris-lang.org/documentation>.
    Features include:

    * Full, first class, dependent types with dependent pattern matching

    * where clauses, with rule, case expressions,
    pattern matching let and lambda bindings

    * Interfaces (similar to type classes), monad comprehensions

    * do notation, idiom brackets, syntactic conveniences for lists,
    tuples, dependent pairs

    * Totality checking

    * Coinductive types

    * Indentation significant syntax, extensible syntax

    * Cumulative universes

    * Simple foreign function interface (to C)

    * Hugs style interactive environment

category:             Compilers/Interpreters, Dependent Types
abi:                  e81296c1e9ebd1ddb49d9a0632a068f3
exposed:              True
exposed-modules:
    IRTS.Bytecode IRTS.CodegenC IRTS.CodegenCommon
    IRTS.CodegenJavaScript IRTS.Compiler IRTS.Defunctionalise
    IRTS.DumpBC IRTS.Exports IRTS.Inliner IRTS.JavaScript.AST
    IRTS.JavaScript.Codegen IRTS.JavaScript.LangTransforms
    IRTS.JavaScript.Name IRTS.JavaScript.PrimOp
    IRTS.JavaScript.Specialize IRTS.Lang IRTS.LangOpts IRTS.Portable
    IRTS.Simplified IRTS.System Idris.ASTUtils Idris.AbsSyntax
    Idris.AbsSyntaxTree Idris.Apropos Idris.CaseSplit Idris.Chaser
    Idris.CmdOptions Idris.Colours Idris.Completion Idris.Core.Binary
    Idris.Core.CaseTree Idris.Core.Constraints Idris.Core.DeepSeq
    Idris.Core.Elaborate Idris.Core.Evaluate Idris.Core.Execute
    Idris.Core.ProofState Idris.Core.ProofTerm Idris.Core.TT
    Idris.Core.Typecheck Idris.Core.Unify Idris.Core.WHNF
    Idris.Coverage Idris.DSL Idris.DataOpts Idris.DeepSeq
    Idris.Delaborate Idris.Directives Idris.Docs Idris.Docstrings
    Idris.Elab.AsPat Idris.Elab.Clause Idris.Elab.Data
    Idris.Elab.Implementation Idris.Elab.Interface Idris.Elab.Provider
    Idris.Elab.Quasiquote Idris.Elab.Record Idris.Elab.Rewrite
    Idris.Elab.RunElab Idris.Elab.Term Idris.Elab.Transform
    Idris.Elab.Type Idris.Elab.Utils Idris.Elab.Value Idris.ElabDecls
    Idris.Erasure Idris.ErrReverse Idris.Error Idris.Help Idris.IBC
    Idris.IdeMode Idris.IdrisDoc Idris.Imports Idris.Info
    Idris.Info.Show Idris.Inliner Idris.Interactive Idris.Main
    Idris.ModeCommon Idris.Options Idris.Output Idris.Package
    Idris.Package.Common Idris.Package.Parser Idris.Parser
    Idris.Parser.Data Idris.Parser.Expr Idris.Parser.Helpers
    Idris.Parser.Ops Idris.Parser.Stack Idris.PartialEval
    Idris.Primitives Idris.ProofSearch Idris.Prover Idris.Providers
    Idris.REPL Idris.REPL.Browse Idris.REPL.Commands Idris.REPL.Parser
    Idris.Reflection Idris.Termination Idris.Transforms
    Idris.TypeSearch Idris.Unlit Idris.WhoCalls Util.DynamicLinker
    Util.ScreenSize Util.System

hidden-modules:
    Util.Pretty Util.Net Paths_idris Version_idris Tools_idris
    BuildFlags_idris

import-dirs:          /usr/lib/ghc-9.0.2/site-local/idris-1.3.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/idris-1.3.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/idris
hs-libraries:         HSidris-1.3.3-FqpR8juFX0xIMsxhVdonFO
extra-libraries:      gmp
depends:
    aeson-1.5.6.0-8jziRWRW6a6EPpU4Gt4Qym
    annotated-wl-pprint-0.7.0-6vyiTB7Qv98BkD7hsY3Ewg
    ansi-terminal-0.11-7Sg6KtenVNR9Ce5shok5FD
    ansi-wl-pprint-0.6.9-2VNLfDMK9dk19FuqhpaBWd array-0.5.4.0
    async-2.2.4-KDuVI0AzzpKOLY6VEiTcY base-4.15.1.0
    base64-bytestring-1.2.1.0-IJfNeffkxdOAxIJzuh3onN binary-0.8.8.0
    blaze-html-0.9.1.2-3dsqqO8mnaT2abRL0rSMos
    blaze-markup-0.8.2.8-A6fzpxGMPsl9AYOr5KEtmS bytestring-0.10.12.1
    cheapskate-0.1.1.2-3hGdSeX7udlFkZ8CXboTfx
    code-page-0.2.1-2yvmeM0b2LT6XlGG4kufG5 containers-0.6.4.1
    deepseq-1.4.5.0 directory-1.3.6.2 filepath-1.4.2.1
    fingertree-0.1.4.2-5x3c5AwrNNkK5JYr99lJj7
    fsnotify-0.3.0.1-H6v4BSenPB5GfdqCXJJcwb haskeline-0.8.2
    ieee754-0.8.0-8ARR0f1c99A76lnIcdz1Si
    libffi-0.1-GJxpon6VMOoBw0Ug9MCPUg
    megaparsec-9.2.0-HXRR17aTU4R3hPA2ys02el mtl-2.2.2
    network-3.1.2.7-8gILzT5LabS6CDprj5uZiN
    optparse-applicative-0.16.1.0-DEjwPOuSPXL9VmbUx7zk3c
    parser-combinators-1.3.0-FL5bcA6sX4a2ejs4tDtkjB pretty-1.1.3.6
    process-1.6.13.2 regex-tdfa-1.3.1.1-KGmZaGzzk3eJJOsPg0zcxp
    safe-0.3.19-2aVM1fCfxX88jnlVeNbd8Q
    split-0.2.3.4-IPPhdaAPLRxBrTyPUVNi43
    terminal-size-0.3.2.1-FigLoTMV11v1o9pkAK81G8 text-1.2.5.0
    time-1.9.3 transformers-0.5.6.2
    uniplate-1.6.13-J0JTVbDxytQ1U4qlAgp6Iw unix-2.7.2.2
    unordered-containers-0.2.15.0-Ht2efffRCvFCdRwsi5oUgT
    utf8-string-1.0.2-9eFA57BgKXNHtjvfuIOq9f
    vector-0.12.3.1-KtKcoCRq29nJlZWgb7i8Fm
    vector-binary-instances-0.2.5.2-66x7zCjtMLuB2zN2VAeBr8
    zip-archive-0.4.1-6VSO3iOj5wzFut3GefFYiW

haddock-interfaces:   /usr/share/doc/idris/html/idris.haddock
haddock-html:         /usr/share/doc/idris/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

